#
# Copyright 2021, Flyreel. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ========================================================================#
"""Top-level module imports."""

# NOTE: Imports PyTorch Lightning first to mitigate an import error.
import pytorch_lightning as _pl

from torch.utils.data import DataLoader

from .datasets import dataset
from .models.backbones.timm import PyTorchImageModels
from .schedulers.lr import PolynomialLR
from .learners import Classifier
